<?php

namespace App\Models;

use Illuminate\Contracts\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Storage;

class Item extends Model
{
    use HasFactory, SoftDeletes;

    protected $fillable = [
        'title',
        'description',
        'video_path',
        'image_path',
        'preview_path',
        'teaser_path',
        'item_id',
        'item_type',
        'section',
        'season',
        'length',
        'production_year',
        'imdb_rating',
        'publish_status',
        'slider_id',
    ];

    public function scopeLatest(Builder $builder)
    {
        return $builder->orderBy(static::CREATED_AT, 'desc');
    }

    public function sections()
    {
        return $this->hasMany(Item::class)->whereNotNull('season')->whereNotNull('section');
    }

    public function pictures()
    {
        return $this->hasMany(Item::class)->whereNull('season')->whereNull('section')->whereNull('slider_id');
    }

    public function filmCasts()
    {
        return $this->belongsToMany(FilmCast::class, 'item_film_cast')->withPivot(['role']);
    }

    public function parent()
    {
        return $this->belongsTo(Item::class);
    }

    public function comments()
    {
        return $this->morphMany(Comment::class, 'comment')->where('confirm', true)->latest();
    }

    public function likes()
    {
        return $this->morphToMany(User::class, 'like')->where('action', 'like')->withTimestamps();
    }

    public function disLikes()
    {
        return $this->morphToMany(User::class, 'like')->where('action', 'dislike')->withTimestamps();
    }

    public function categories()
    {
        // return $this->belongsToMany(Category::class, 'category_item');
        return $this->morphToMany(Category::class, 'categorizable')->latest();
    }

    public function favedBy()
    {
        return $this->belongsToMany(User::class, 'favorites');
    }

    public function slider()
    {
        return $this->belongsTo(Slider::class);
    }

    public function countries()
    {
        return $this->belongsToMany(Country::class, 'item_country');
    }

    public function voicesAndSubtitles()
    {
        return $this->belongsToMany(VoiceAndSubtitle::class, 'item_voice_subtitle')->orderBy('type', 'asc');
    }

    public function questionPackage()
    {
        return $this->hasOne(QuestionPackage::class);
    }

    // public function voices()
    // {
    //     return $this->belongsToMany(Voice::class, 'item_voice');
    // }

    // public function image_url()
    // {
    //     return Storage::url($this->image_path);
    // }
}
