<?php

namespace App\Repository\Eloquent;

use App\Http\Resources\PlanResource;
use App\Models\Category;
use App\Models\DiscountCode;
use App\Models\Plan;
use App\Models\UsedDiscountCode;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

use function PHPUnit\Framework\isNull;

class DiscountCodeRepository extends BaseRepository{


    //---------------------------------------------------------------------------------------------------
    
    public function checkDiscountCode(Request $request)
    {
        $discountCode = DiscountCode::where('code', $request->code)->first();

        if(is_null($discountCode)){
            return $this->sendError('کد تخفیف معتبر نمیباشد');
        } else {
            if(!is_null(UsedDiscountCode::where('user_id', Auth::user()->id)->where('discount_code_id', $discountCode->id)->first()))
                return $this->sendError('کد تخفیف معتبر نمیباشد');

            $plans = PlanResource::collection(Plan::all())->each(function ($plan) use($discountCode){

                $discount = $plan['price'] * (($discountCode['discount_percent'])/100);
                if(!is_null($discountCode['maximum_discount']))
                    if($discount < $discountCode['maximum_discount'])
                        $plan['price'] = $plan['price'] - $discount;
                    else
                        $plan['price'] = $plan['price'] - $discountCode['maximum_discount'];
                else
                    $plan['price'] = $discount;

            });

            Auth::user()->usedDiscountCodes()->attach([$discountCode->id]);

            return $this->sendResponse($plans);
        }

        
        

    }
    

}

?>