<?php

namespace App\Repository\Eloquent;

use App\Http\Requests\StoreItem;
use App\Http\Resources\CommentResource;
use App\Http\Resources\CompactItemResource;
use App\Http\Resources\FilmCastResource;
use App\Http\Resources\ItemResource;
use App\Http\Resources\SeasonResource;
use App\Http\Resources\SectionResource;
use App\Http\Resources\SliderResource;
use App\Models\Item;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ItemRepository extends BaseRepository{

    protected $model;

    public function __construct(Item $model)
    {
        $this->model = $model;
    }

    //--------------------------------------------------------------------------------------


    public function getItem(Request $request)
    {
        $item = Item::find($request->id);
        $item = $this->fillLikeAndRating($item);

        // return $item;

        // return $item;

        // if($item['item_type'] === 'serial'){ //get seasons and sections

        //     $itemSections = $item->sections;
        //     $subtitle = $item->subtitle;
        //     if(is_null($subtitle))  
        //         $data['subtitle'] = false;
        //     else{
        //         unset($item['subtitle']);
        //         $data['subtitle'] = true;
        //     }
        //     unset($item['sections']);
            
        //     $sections = [];
        //     foreach($itemSections as $section){
        //         $section = $this->fillLikeAndRating($section);
        //         $sections[$section->season][$section->section] = new ItemResource($section);
                
        //     }
        //     $item['sections'] = $sections;

        // }

        $item->pictures;
        $item->filmCasts;
        $item->slider;
        $item->voicesAndSubtitles;

        $data = new ItemResource($item);
        return $this->sendResponse($data);
    }

    //--------------------------------------------------------------------------------------

    public function getSections(Request $request)
    {

        $item = Item::find($request->id);
        $itemSections = $item->sections;
        unset($item['sections']);
        
        $sections = [];
        foreach($itemSections as $section){
            $section = $this->fillLikeAndRating($section);
            $sections[$section->season - 1][$section->section] = $section;
        }

        

        foreach($sections as $seasonNumber => $section){
            $sections[$seasonNumber] = SectionResource::collection($section);
        }

        // $data = SeasonResource::collection($sections);
        // dd($sections[1]);
        // return $sections;

        return $this->sendResponse($sections);
        
    }

    //--------------------------------------------------------------------------------------

    public function getSimilars(Request $request)
    {
        $data = [];
        $item = Item::find($request->id);
        $categoriesId = $item->categories->pluck('id');
        // return $categories;

        $items = Item::whereHas('categories', function ($query) use($categoriesId) {
            $query->whereIn('category_id', $categoriesId);
        })->where('id', '!=', $item->id)->where('item_type', $item->item_type)->get();

        return $this->sendResponse(CompactItemResource::collection($items));
        
    }

    private function fillLikeAndRating(Item $item) // also fills action and faved
    {

        $likesCount = $item->likes->count();
        $disLikesCount = $item->disLikes->count();

        // return $item->likes;

        $item['rating'] = null;
        if($likesCount != 0){
            $item['rating'] = ($likesCount/($likesCount + $disLikesCount)) * 100;
        }

        $item['action'] = null;
        $item['favorite'] = false;
        $user = auth('sanctum')->user();
        // return $user;
        if(!is_null($user)){

            if(!is_null($item->favedBy)){
                $like =  $item->favedBy->search(function($like) use($user){
                        return $like->id == $user->id;
                    });
                if($like !== false){
                    $item['favorite'] = 'true';
                }
            }






            if(!is_null($item->likes)){
                $like =  $item->likes->search(function($like) use($user){
                        return $like->id == $user->id;
                    });
                if($like !== false){
                    $item['action'] = 'like';
                }
            }

            if(!is_null($item->disLikes)){

                $disLike =  $item->disLikes->search(function($like) use($user){
                    return $like->id == $user->id;
                });
                if($disLike !== false){
                    $item['action'] = 'dislike';
                }
            }
        }
        
        unset($item->disLikes);
        unset($item->likes);

        return $item;
        
    }

    public function store(StoreItem $request)
    {

        $data = [];
        $validatedData          = $request->validated();
        $data['title']          = $validatedData['title'];
        $data['description']    = $validatedData['description'];

        if($request->hasFile('image'))
            $data['image_path']     = $request->file('image')->store('images');
        if($request->hasFile('video'))
            $data['video_path']     = $request->file('video')->store('videos');
        if($request->hasFile('preview'))
            $data['preview_path']   = $request->file('preview')->store('previews');
        if($request->hasFile('teaser'))
            $data['teaser_path']    = $request->file('teaser')->store('teasers');

        // return $data;

        $item = Item::create($data);

        return $this->sendResponse();
        
    }

}

?>