<?php

namespace App\Repository\Eloquent;

use App\Http\Resources\CompactItemResource;
use App\Http\Resources\SearchFieldsResource;
use App\Models\Category;
use App\Models\Country;
use App\Models\FilmCast;
use App\Models\Item;
use App\Models\Subtitle;
use App\Models\Voice;
use App\Models\VoiceAndSubtitle;
use Illuminate\Http\Request;
use PHPUnit\Framework\Constraint\Count;

class SearchRepository extends BaseRepository{


    // public function searchByKeyword(Request $request)
    // {

    //     $data = [];
    //     $data['items']      = Item::where    ('title', 'LIKE', '%' . $request->keyword . '%')->get();
    //     $data['film_casts'] = FilmCast::where('name' , 'LIKE', '%' . $request->keyword . '%')->get();
    //     $data['categories'] = Category::where('name' , 'LIKE', '%' . $request->keyword . '%')->get();
    //     return $this->sendResponse();
    // }

    public function search(Request $request)
    {

        $items = new Item();
        if($request->has('show_type') && !$request->show_type === 'all'){
            $items->where('show_type', $request->show_type);
        }

        if($request->has('keyword')){
            $items->where    ('title', 'LIKE', '%' . $request->keyword . '%');
        }

        if($request->has('categories')){
            $items = $items->whereHas('categories', function ($query) use($request) {
                $query->whereIn('category_id', $request->categories);
            });
        }

        if($request->has('countries')){
            $items = $items->whereHas('countries', function ($query) use($request) {
                $query->whereIn('country_id', $request->countries);
            });
        }

        if($request->has('voices_and_subtitle')){
            $items = $items->whereHas('voices_and_subtitle', function ($query) use($request) {
                $query->whereIn('voice_subtitle_id', $request->voices_and_subtitle);
            });
        }

        // if($request->has('subtitles')){
        //     $items = $items->whereHas('subtitles', function ($query) use($request) {
        //         $query->whereIn('subtitle_id', $request->subtitles);
        //     });
        // }

        if($request->has('production_year')){
            // $items->whereIn('country', $request->countries);
            $items->whereBetween('production_year', [$request->production_year['from'], $request->production_year['to']]);
        }

        if($request->has('ordered_by')){

            if($request->ordered_by === 'new'){
                $items->orderBy('created_at', 'desc');
            } elseif($request->ordered_by === 'imdb_rate'){
                $items->orderBy('imdb_rating', 'desc');
            } elseif($request->ordered_by === 'production_year_new'){
                $items->orderBy('production_year', 'desc');
            } elseif($request->ordered_by === 'production_year_old'){
                $items->orderBy('production_year', 'asc');
            }

        }

        return $this->sendResponse(CompactItemResource::collection($items->get()));
    }

    public function getSearchFields()
    {

        $data = [];
        $data['categories']             = SearchFieldsResource::collection(Category::all());
        $data['countries']              = SearchFieldsResource::collection(Country::all());
        $data['voices_and_subtitle']    = SearchFieldsResource::collection(VoiceAndSubtitle::subtitleFirst()->get());

        return $this->sendResponse($data);
    }


}

?>